{% extends "admin/change_list.html" %}
{% comment %}This is a dummy fix for the mptt template trying to load the deprecated adminmedia tag, invalid for django >= 1.5
Since djangocms 2.4.3 is blocked on mptt 0.5.2 only, we can't use mptt 0.5.5 that contain this fix.
So we are doing it here as an override..{% endcomment %}
{% load admin_list i18n mptt_admin %}

{% block result_list %}
    {% if action_form and actions_on_top and cl.full_result_count %}{% admin_actions %}{% endif %}
    {% mptt_result_list cl %}
    {% if action_form and actions_on_bottom and cl.full_result_count %}{% admin_actions %}{% endif %}
{% endblock %}
