{% load i18n %}
<ul>
    {% for object in object_list %}
    <li class="panel radius">
        <a href="{% url 'porticus-gallery-detail' gallery_slug=object.slug %}">{{ object }}</a>
    </li>
    {% empty %}
    <li class="empty">{% trans "No gallery" %}</li>
    {% endfor %}
</ul>
